@@ -16,6 +16,7 @@ import uuid
 from django.conf import settings
 from django.contrib import auth
 from django import test
+from django.test.utils import override_settings
 from django.urls import reverse
 from keystoneauth1 import exceptions as keystone_exceptions
 from keystoneauth1.identity import v2 as v2_auth
@@ -89,7 +90,7 @@ class OpenStackAuthTestsMixin(object):
                 auth=plugin)
 
     def get_form_data(self, user):
-        return {'region': settings.OPENSTACK_KEYSTONE_URL,
+        return {'region': "default",
                 'domain': DEFAULT_DOMAIN,
                 'password': user.password,
                 'username': user.name}
@@ -1170,7 +1171,7 @@ class OpenStackAuthTestsWebSSO(OpenStackAuthTestsMixin,
                         (settings.OPENSTACK_KEYSTONE_URL, protocol, origin))
 
         form_data = {'auth_type': protocol,
-                     'region': settings.OPENSTACK_KEYSTONE_URL}
+                     'region': 'default'}
         url = reverse('login')
 
         # POST to the page and redirect to keystone.
@@ -1187,7 +1188,7 @@ class OpenStackAuthTestsWebSSO(OpenStackAuthTestsMixin,
                          protocol, origin))
 
         form_data = {'auth_type': self.idp_oidc_id,
-                     'region': settings.OPENSTACK_KEYSTONE_URL}
+                     'region': 'default'}
         url = reverse('login')
 
         # POST to the page and redirect to keystone.
@@ -1195,6 +1196,25 @@ class OpenStackAuthTestsWebSSO(OpenStackAuthTestsMixin,
         self.assertRedirects(response, redirect_url, status_code=302,
                              target_status_code=404)
 
+    @override_settings(WEBSSO_KEYSTONE_URL='http://keystone-public:5000/v3')
+    def test_websso_redirect_using_websso_keystone_url(self):
+        origin = 'http://testserver/auth/websso/'
+        protocol = 'oidc'
+        redirect_url = ('%s/auth/OS-FEDERATION/identity_providers/%s'
+                        '/protocols/%s/websso?origin=%s' %
+                        (settings.WEBSSO_KEYSTONE_URL, self.idp_id,
+                         protocol, origin))
+
+        form_data = {'auth_type': self.idp_oidc_id,
+                     'region': 'default'}
+        url = reverse('login')
+
+        # POST to the page and redirect to keystone.
+        response = self.client.post(url, form_data)
+        # verify that the request was sent back to WEBSSO_KEYSTONE_URL
+        self.assertRedirects(response, redirect_url, status_code=302,
+                             target_status_code=404)
+
     def test_websso_login(self):
         projects = [self.data.project_one, self.data.project_two]
         domains = []
@@ -1237,4 +1257,34 @@ class OpenStackAuthTestsWebSSO(OpenStackAuthTestsMixin,
         response = self.client.post(url, form_data)
         self.assertRedirects(response, settings.LOGIN_REDIRECT_URL)
 
+    def test_websso_login_default_redirect(self):
+        origin = 'http://testserver/auth/websso/'
+        protocol = 'oidc'
+        redirect_url = ('%s/auth/OS-FEDERATION/websso/%s?origin=%s' %
+                        (settings.OPENSTACK_KEYSTONE_URL, protocol, origin))
+
+        settings.WEBSSO_DEFAULT_REDIRECT = True
+        settings.WEBSSO_DEFAULT_REDIRECT_PROTOCOL = 'oidc'
+        settings.WEBSSO_DEFAULT_REDIRECT_REGION = (
+            settings.OPENSTACK_KEYSTONE_URL)
+
+        url = reverse('login')
+
+        # POST to the page and redirect to keystone.
+        response = self.client.get(url)
+        self.assertRedirects(response, redirect_url, status_code=302,
+                             target_status_code=404)
+
+    def test_websso_logout_default_redirect(self):
+        settings.WEBSSO_DEFAULT_REDIRECT = True
+        settings.WEBSSO_DEFAULT_REDIRECT_LOGOUT = 'http://idptest/logout'
+
+        url = reverse('logout')
+
+        # POST to the page and redirect to logout method from idp.
+        response = self.client.get(url)
+        self.assertRedirects(response, settings.WEBSSO_DEFAULT_REDIRECT_LOGOUT,
+                             status_code=302, target_status_code=301)
+
+
 load_tests = load_tests_apply_scenarios
