@@ -15,7 +15,7 @@
 import logging
 
 from django.conf import settings
-from django.core.urlresolvers import reverse
+from django.urls import reverse
 from django.utils.translation import ugettext_lazy as _
 
 from openstack_auth import utils
@@ -327,7 +327,7 @@ class UpdateDomain(workflows.Workflow):
                                                domain=domain_id)
             users_dict = {user.id: user.name for user in all_users}
 
-            for user_id in users_roles.keys():
+            for user_id in users_roles:
                 # Don't remove roles if the user isn't in the domain
                 if user_id not in users_dict:
                     users_to_modify -= 1
@@ -368,7 +368,7 @@ class UpdateDomain(workflows.Workflow):
                 ]
                 admin_role_ids = [role for role in current_role_ids
                                   if role in available_admin_role_ids]
-                if len(admin_role_ids):
+                if admin_role_ids:
                     removing_admin = any([role in current_role_ids
                                           for role in admin_role_ids])
                 else:
@@ -472,8 +472,9 @@ class UpdateDomain(workflows.Workflow):
             for role in available_roles:
                 groups_added = 0
                 field_name = member_step.get_member_field_name(role.id)
+                domain_group_ids = [x.id for x in domain_groups]
                 for group_id in data[field_name]:
-                    if not filter(lambda x: group_id == x.id, domain_groups):
+                    if group_id not in domain_group_ids:
                         api.keystone.add_group_role(request,
                                                     role=role.id,
                                                     group=group_id,
